@@ -1,3 +1,10 @@
+"""Batch processing utility functions.
+
+geoapify.com offers several of its services in a batch version. They all work the same: you start with a list of
+records and ask to process each component. Processing is component-wise independent and can be POSTed in a batch
+instead requesting for each component separately. Geoapify is able to distribute processing on its servers. You can
+use GET requests to ask if a job is completed. If it is, you can GET the results for a complete batch.
+"""
 import logging
 import math
 import time
@@ -119,7 +126,7 @@ class BatchClient:
 
         Use either place_ids or geocodes to encode your inputs. place_ids is prioritized if both are not None.
 
-        See the Geoapify API docs for a list of available features.
+        See the Geoapify.com API docs for a list of available features.
 
         Arguments:
             place_ids: list of place_id values.
